@@ -22,20 +22,18 @@
 #' @param maxTry maximum number of restarts of the SEM-Gibbs algorithm in the case of non convergence (default value=3).
 #' @param run number of runs of the algorithm for each value of K.
 #' @param detail boolean, if TRUE, time and others informations will be print during the process (default value FALSE).
+#' 
 #' @return An object of class rankclust (See \code{\link{Output-class}} and \code{\link{Rankclust-class}}).
-#'
-#' For example :
-#' res=rankclust(data,K=1:2,m=m)
-#'
-#' You can access the result by res[number of groups]@@slotName where slotName is an element of the class Output.
+#' If the output object is named \code{res}. You can access the result by res[number of groups]@@slotName where \code{slotName} is an element of the class Output.
+#' 
 #' @references 
 #' [1] C.Biernacki and J.Jacques (2013), A generative model for rank data based on sorting algorithm, Computational Statistics and Data Analysis, 58, 162-176.
 #'
-#'[2] J.Jacques and C.Biernacki (2012), Model-based clustering for multivariate partial ranking data, Inria Research Report n 8113.
+#' [2] J.Jacques and C.Biernacki (2012), Model-based clustering for multivariate partial ranking data, Inria Research Report n 8113.
 #'
 #' @examples
 #' data(big4)
-#' result=rankclust(big4$data,K=2,m=big4$m,Ql=200,Bl=100,maxTry=2)
+#' result = rankclust(big4$data, K = 2, m = big4$m, Ql = 200, Bl = 100, maxTry = 2)
 #' 
 #' @details
 #' 
@@ -172,13 +170,13 @@ rankclust <- function(data, m = ncol(data), K = 1, criterion = "bic", Qsem = 100
   #RjM
   if(!is.numeric(RjM) || (length(RjM)!=length(m)))
     stop("RjM must be a vector of strictly positive integer")
-  if( (RjM!=round(RjM)) || (RjM<=0))
+  if(any((RjM!=round(RjM)) | (RjM<=0)))
     stop("RjM must be a vector of strictly positive integer")
   
   #RjSE
   if(!is.numeric(RjSE) || (length(RjSE)!=length(m)))
     stop("RjSE must be a vector of strictly positive integer")
-  if( (RjSE!=round(RjSE)) || (RjSE<=0))
+  if(any((RjSE!=round(RjSE)) | (RjSE<=0)))
     stop("RjSE must be a vector of strictly positive integer")
   
   #Ql
